@@ -1,7 +1,7 @@
 fmt_privacy = {
-    None: 'default',
-    True: 'public',
-    False: 'private',
+    None: "default",
+    True: "public",
+    False: "private",
 }
 
 
@@ -9,14 +9,14 @@ def main(ctx):
     if ctx is None:
         print("Compilation failed")
     else:
-        for node in ctx.astnode_types:
+        for node in ctx.node_types:
             if node.kwless_raw_name.camel in ("AbstractNode", "ConcreteNode"):
                 for name, fld in sorted(node._fields.items()):
                     if name == "prop":
                         print(
                             "  {}: {}".format(
                                 fld.qualname,
-                                fmt_privacy[fld.original_is_public]
+                                fmt_privacy[fld.original_is_public],
                             )
                         )
     print("")
